/**
 * The purpose of this groovy script is to return all default libraries locations for Tomcat 5.x.
 *
 * EXPECTED INPUT:
 *		TOMCATHOME : the location of Tomcat installation
 *		EXOSRC     : the location of eXo source code main directory 
 *		VMInstall  : an instance of IVMInstall that represents the JDK to use for this configuration
 *
 * EXPECTED OUTPUT:
 *
 *		binLibraries    : all the jar files under the bin directory of Tomcat. These jar files are in 
 *						  a list of elements where each element in the list is a map. Each map might 
 *						  have one of the following keys:
 *						  	classes:  the path to a jar file or a folder that contains classes
 *							src:      the path to a zip file or a folder that contains the source code
 *							src-root: the path of the root source folder within a given src zip file.
 *									  only makes sense if the 'src' key has a value too.
 *
 *		serverlibraries : all the libraries that are used for the Tomcat server.
 *						  these libraries are returned in a list of elements just like binLibraries.
 * 
 *		commonLibraries : all the libraries that are considered common in terms of Tomcat. 
 *						  these libraries are returned in a list of elements just like binLibraries.
 * 
 *		sharedLibraries : all the libraries that are considered shared in terms of Tomcat. 
 *						  these libraries are returned in a list of elements just like binLibraries.
 *
 *		serverWebappsLibraries : all the libraries that are used by the webapps under the server part 
 *								 of Tomcat. These libraries are returned in a list of elements 
 *								 just like binLibraries.
 *
 *		defaultWebappsLibraries : all the libraries that are used by with the default webapps that are 
 *								  shipped with Tomcat. These libraries are returned in a list of elements 
 *								  just like binLibraries.
 *
 *		classpathLibraries	: all the libraries that need to be in classpath while starting Tomcat.
 *							  These libraries are returned in a list of elements just like binLibraries.
 *							  Note that the classpath libraries can be directories.
 *
 *		endorsedLibraries	: all the libraries that should be treated as endorsed while starting Tomcat.
 *							  These libraries are returned in a list of elements just like binLibraries.
 *							  Note that you still have to supply a vm argument for the endorsed directories.
 * 
 *		VMArguments 	: all the VM arguments required to start Tomcat. Note the you don't need to
 *						  include the classpath libraries in the arguments since they are supplied 
 *						  (see above). However, you still need to supply the endorsed directories as vm
 *						  arguments. All VM arguments are put in a list, and each element in the list is 
 *						  a map. Each map should have the following keys:
 *								key: 	the key of an argument entry. For example, '-Djava.io.tempdir'.
 *								value: 	the value of the argument.
 *								type: 	a String the represents the type of the VMArguments. Please see
 *									  	the comments in the VMArgumentType class.
 *
 */

if (TOMCATHOME == null) tomcatRoot = "";
else tomcatRoot=TOMCATHOME;

if (EXOSRC == null) exoSrc="";
else exoSrc=EXOSRC;

jdkRoot=VMInstall.getInstallLocation().getAbsolutePath();

///////////////////////////////////////// commonLibraries /////////////////////////////////////////////
commonLibraries=[];

commonLibraries.add(['classes': tomcatRoot + '/common/lib/exoplatform.commons-1.0.jar',
                     'src'    : exoSrc + '/commons/src/java']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exoplatform.container-1.0.jar',
                     'src'    : exoSrc + '/container/src/java']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exoplatform.jsf-components-1.0.jar',
                     'src'    : exoSrc + '/jsf-components/src/java']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exoplatform.portal-1.0.jar',
                     'src'    : exoSrc + '/portal/src/java']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exoplatform.portlet-framework.cocoon-1.0.jar',
                     'src'    : exoSrc + '/portlet-framework/cocoon/src/java']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exoplatform.portlet-framework.exomvc-1.0.jar',
                     'src'    : exoSrc + '/portlet-framework/exomvc/src/java']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exoplatform.portlet-framework.jsf-1.0.jar',
                     'src'    : exoSrc + '/portlet-framework/jsf/src/java']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exoplatform.portlet-framework.struts-1.0.jar',
                     'src'    : exoSrc + '/portlet-framework/struts/src/java']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exoplatform.services.backup.api-1.0.jar',
                     'src'    : exoSrc + '/services/backup/api/src/java']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exoplatform.services.backup.impl-1.0.jar',
                     'src'    : exoSrc + '/services/backup/impl/src/java']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exoplatform.services.cms.impl-1.0.jar',
                     'src'    : exoSrc + '/services/cms/impl/src/java']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exoplatform.services.common.api-1.0.jar',
                     'src'    : exoSrc + '/services/common/api/src/java']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exoplatform.services.common.impl-1.0.jar',
                     'src'    : exoSrc + '/services/common/impl/src/java']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exoplatform.services.communication.api-1.0.jar',
                     'src'    : exoSrc + '/services/communication/api/src/java']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exoplatform.services.communication.impl-1.0.jar',
                     'src'    : exoSrc + '/services/communication/impl/src/java']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exoplatform.services.database.api-1.0.jar',
                     'src'    : exoSrc + '/services/database/api/src/java']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exoplatform.services.database.impl-1.0.jar',
                     'src'    : exoSrc + '/services/database/impl/src/java']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exoplatform.services.id-generator.api-1.0.jar',
                     'src'    : exoSrc + '/services/id-generator/api/src/java']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exoplatform.services.id-generator.impl-1.0.jar',
                     'src'    : exoSrc + '/services/id-generator/impl/src/java']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exoplatform.services.indexing.api-1.0.jar',
                     'src'    : exoSrc + '/services/indexing/api/src/java']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exoplatform.services.indexing.impl-1.0.jar',
                     'src'    : exoSrc + '/services/indexing/impl/src/java']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exoplatform.services.jcr.api-1.0.jar',
                     'src'    : exoSrc + '/services/jcr/api/src/java']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exoplatform.services.jcr.impl-1.0.jar',
                     'src'    : exoSrc + '/services/jcr/impl/src/java']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exoplatform.services.ldap.api-1.0.jar',
                     'src'    : exoSrc + '/services/ldap/api/src/java']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exoplatform.services.ldap.impl-1.0.jar',
                     'src'    : exoSrc + '/services/ldap/impl/src/java']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exoplatform.services.organization.api-1.0.jar',
                     'src'    : exoSrc + '/services/organization/api/src/java']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exoplatform.services.organization.impl-1.0.jar',
                     'src'    : exoSrc + '/services/organization/impl/src/java']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exoplatform.services.portal.api-1.0.jar',
                     'src'    : exoSrc + '/services/portal/api/src/java']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exoplatform.services.portal.impl-1.0.jar',
                     'src'    : exoSrc + '/services/portal/impl/src/java']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exoplatform.services.portlet-container.api-1.0.jar',
                     'src'    : exoSrc + '/services/portlet-container/api/src/java']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exoplatform.services.portlet-container.impl-1.0.jar',
                     'src'    : exoSrc + '/services/portlet-container/impl/src/java']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exoplatform.services.portlet-registry.api-1.0.jar',
                     'src'    : exoSrc + '/services/portlet-registry/api/src/java']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exoplatform.services.portlet-registry.impl-1.0.jar',
                     'src'    : exoSrc + '/services/portlet-registry/impl/src/java']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exoplatform.services.resources.api-1.0.jar',
                     'src'    : exoSrc + '/services/resources/api/src/java']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exoplatform.services.resources.impl-1.0.jar',
                     'src'    : exoSrc + '/services/resources/impl/src/java']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exoplatform.services.security.api-1.0.jar',
                     'src'    : exoSrc + '/services/security/api/src/java']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exoplatform.services.security.impl-1.0.jar',
                     'src'    : exoSrc + '/services/security/impl/src/java']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exoplatform.services.workflow.api-1.0.jar',
                     'src'    : exoSrc + '/services/workflow/api/src/java']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exoplatform.services.workflow.impl-1.0.jar',
                     'src'    : exoSrc + '/services/workflow/impl/src/java']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exoplatform.services.wsrp.api-1.0.jar',
                     'src'    : exoSrc + '/services/wsrp/api/src/java']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exoplatform.services.wsrp.impl-1.0.jar',
                     'src'    : exoSrc + '/services/wsrp/impl/src/java']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exoplatform.services.xml-processing.api-1.0.jar',
                     'src'    : exoSrc + '/services/xml-processing/api/src/java']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exoplatform.services.xml-processing.impl-1.0.jar',
                     'src'    : exoSrc + '/services/xml-processing/impl/src/java']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exoplatform.test.webunit-framework-1.0.jar',
                     'src'    : exoSrc + '/test/webunit-framework/src/java']);

////////////////////////////////////// defaultWebappsLibraries ///////////////////////////////////////////
defaultWebappsLibraries=[];

defaultWebappsLibraries.add(['classes': tomcatRoot + '/webapps/admin/WEB-INF/classes',
                             'src'    : exoSrc + '/portlets/core/admin/src/java']);
defaultWebappsLibraries.add(['classes': tomcatRoot + '/webapps/communications/WEB-INF/classes',
                             'src'    : exoSrc + '/portlets/core/communications/src/java']);
defaultWebappsLibraries.add(['classes': tomcatRoot + '/webapps/content/WEB-INF/classes',
                             'src'    : exoSrc + '/portlets/core/content/src/java']);
defaultWebappsLibraries.add(['classes': tomcatRoot + '/webapps/exomvc/WEB-INF/classes',
                             'src'    : exoSrc + '/portlets/core/exomvc/src/java']);
defaultWebappsLibraries.add(['classes': tomcatRoot + '/webapps/navigation/WEB-INF/classes',
                             'src'    : exoSrc + '/portlets/core/navigation/src/java']);
defaultWebappsLibraries.add(['classes': tomcatRoot + '/webapps/user/WEB-INF/classes',
                             'src'    : exoSrc + '/portlets/core/user/src/java']);
defaultWebappsLibraries.add(['classes': tomcatRoot + '/webapps/web/WEB-INF/classes',
                             'src'    : exoSrc + '/portlets/core/web/src/java']);
defaultWebappsLibraries.add(['classes': tomcatRoot + '/webapps/workflow/WEB-INF/classes',
                             'src'    : exoSrc + '/portlets/core/workflow/src/java']);
defaultWebappsLibraries.add(['classes': tomcatRoot + '/webapps/wsrp/WEB-INF/classes',
                             'src'    : exoSrc + '/portlets/core/wsrp/src/java']);
defaultWebappsLibraries.add(['classes': tomcatRoot + '/webapps/weather/WEB-INF/classes',
                             'src'    : exoSrc + '/portlets/ext/weather/src/java']);

/////////////////////////////////////////// VMArguments ///////////////////////////////////////////////
VMArguments=[];
VMArguments.add(['key':'-Djava.security.auth.login.config','type':'c=multi,p=path,s=assign','value':tomcatRoot +'/conf/jaas.conf']);